@@ -9,8 +9,8 @@
    Author: Mirko Viviani <mirko.viviani@rccr.cremona.it>
    Date: February 2000
 
-   $Revision: 1.19 $
-   $Date: 2004/02/26 14:18:04 $
+   $Revision: 1.21 $
+   $Date: 2004/03/19 16:41:18 $
 
    <abstract></abstract>
 
@@ -36,7 +36,7 @@
 
 #include "config.h"
 
-RCS_ID("$Id: EOAdaptor.m,v 1.19 2004/02/26 14:18:04 ayers Exp $")
+RCS_ID("$Id: EOAdaptor.m,v 1.21 2004/03/19 16:41:18 ayers Exp $")
 
 #if HAVE_LIBC_H
 # include <libc.h>
@@ -46,7 +46,7 @@ RCS_ID("$Id: EOAdaptor.m,v 1.19 2004/02/26 14:18:04 ayers Exp $")
 #endif /* !__WIN32__ */
 #endif
 
-#ifndef NeXT_Foundation_LIBRARY
+#ifdef GNUSTEP
 #include <Foundation/NSArray.h>
 #include <Foundation/NSString.h>
 #include <Foundation/NSPathUtilities.h>
@@ -766,9 +766,9 @@ NSString *EOAdministrativeConnectionDictionaryKey
 }
 
 /**
- * Attempts to create a database using 
+ * Attempts to drop a database using 
  * the statments returned by the Adaptor's expression class
- * for @selector(createDatabaseStatementsForConnectionDictionary:administrativeConnectionDictionary:);
+ * for @selector(dropDatabaseStatementsForConnectionDictionary:administrativeConnectionDictionary:);
  * using the connectionDictionary as the administrative connection dictionary. 
  */
 - (void)dropDatabaseWithAdministrativeConnectionDictionary: (NSDictionary *)connectionDictionary
@@ -1000,7 +1000,11 @@ NSString *EOAdministrativeConnectionDictionaryKey
   [self subclassResponsibility: _cmd];
   return nil;
 }
-
+/** 
+   Subclasses should implement this method to return a connection dictionary
+   for an administrative user able to create databases etc. Or nil if the  
+   the user cancels.
+*/
 - (NSDictionary *) administrativeConnectionDictionaryForAdaptor: (EOAdaptor *)adaptor
 {
   [self subclassResponsibility: _cmd];
