@@ -6,8 +6,8 @@
    Author: Mirko Viviani <mirko.viviani@rccr.cremona.it>
    Date: February 2000
 
-   $Revision: 1.11 $
-   $Date: 2004/01/29 13:23:21 $
+   $Revision: 1.12 $
+   $Date: 2004/03/19 16:41:18 $
 
    <abstract></abstract>
 
@@ -33,9 +33,9 @@
 
 #include "config.h"
 
-RCS_ID("$Id: EOAdaptorChannel.m,v 1.11 2004/01/29 13:23:21 ayers Exp $")
+RCS_ID("$Id: EOAdaptorChannel.m,v 1.12 2004/03/19 16:41:18 ayers Exp $")
 
-#ifndef NeXT_Foundation_LIBRARY
+#ifdef GNUSTEP
 #include <Foundation/NSString.h>
 #include <Foundation/NSArray.h>
 #include <Foundation/NSDictionary.h>
