@@ -9,8 +9,8 @@
    Author: Manuel Guesdon <mguesdon@orange-concept.com>
    Date: October 2000
 
-   $Revision: 1.16 $
-   $Date: 2004/01/31 13:57:24 $
+   $Revision: 1.17 $
+   $Date: 2004/03/19 16:41:18 $
 
    <abstract></abstract>
 
@@ -36,12 +36,12 @@
 
 #include "config.h"
 
-RCS_ID("$Id: EOAttribute.m,v 1.16 2004/01/31 13:57:24 ayers Exp $")
+RCS_ID("$Id: EOAttribute.m,v 1.17 2004/03/19 16:41:18 ayers Exp $")
 
 #include <ctype.h>
 #include <string.h>
 
-#ifndef NeXT_Foundation_LIBRARY
+#ifdef GNUSTEP
 #include <Foundation/NSUtilities.h>
 #include <Foundation/NSArchiver.h>
 #include <Foundation/NSObjCRuntime.h>
