@@ -9,8 +9,8 @@
    Author: Manuel Guesdon <mguesdon@orange-concept.com>
    Date: October 2000
 
-   $Revision: 1.10 $
-   $Date: 2004/01/29 13:23:21 $
+   $Revision: 1.11 $
+   $Date: 2004/03/19 16:41:18 $
 
    <abstract></abstract>
 
@@ -36,9 +36,9 @@
 
 #include "config.h"
 
-RCS_ID("$Id: EODatabaseChannel.m,v 1.10 2004/01/29 13:23:21 ayers Exp $")
+RCS_ID("$Id: EODatabaseChannel.m,v 1.11 2004/03/19 16:41:18 ayers Exp $")
 
-#ifndef NeXT_Foundation_LIBRARY
+#ifdef GNUSTEP
 #include <Foundation/NSString.h>
 #include <Foundation/NSArray.h>
 #include <Foundation/NSDictionary.h>
