@@ -9,8 +9,8 @@
    Author: Manuel Guesdon <mguesdon@orange-concept.com>
    Date: October 2000
 
-   $Revision: 1.17 $
-   $Date: 2004/01/31 13:57:24 $
+   $Revision: 1.18 $
+   $Date: 2004/03/19 16:41:19 $
 
    <abstract></abstract>
 
@@ -36,9 +36,9 @@
 
 #include "config.h"
 
-RCS_ID("$Id: EORelationship.m,v 1.17 2004/01/31 13:57:24 ayers Exp $")
+RCS_ID("$Id: EORelationship.m,v 1.18 2004/03/19 16:41:19 ayers Exp $")
 
-#ifndef NeXT_Foundation_LIBRARY
+#ifdef GNUSTEP
 #include <Foundation/NSArray.h>
 #include <Foundation/NSUtilities.h>
 #include <Foundation/NSException.h>
