@@ -9,8 +9,8 @@
    Author: Manuel Guesdon <mguesdon@orange-concept.com>
    Date: November 2001
 
-   $Revision: 1.19 $
-   $Date: 2004/02/25 12:52:59 $
+   $Revision: 1.20 $
+   $Date: 2004/03/19 16:41:19 $
 
    <abstract></abstract>
 
@@ -36,11 +36,11 @@
 
 #include "config.h"
 
-RCS_ID("$Id: EOSQLExpression.m,v 1.19 2004/02/25 12:52:59 ayers Exp $")
+RCS_ID("$Id: EOSQLExpression.m,v 1.20 2004/03/19 16:41:19 ayers Exp $")
 
 #include <string.h>
 
-#ifndef NeXT_Foundation_LIBRARY
+#ifdef GNUSTEP
 #include <Foundation/NSString.h>
 #include <Foundation/NSSet.h>
 #include <Foundation/NSUtilities.h>
