@@ -6,8 +6,8 @@
    Author: Manuel Guesdon <mguesdon@orange-concept.com>
    Date: Sep 2000
 
-   $Revision: 1.8 $
-   $Date: 2004/01/29 13:23:22 $
+   $Revision: 1.9 $
+   $Date: 2004/03/19 16:41:19 $
 
    <abstract></abstract>
 
@@ -33,9 +33,9 @@
 
 #include "config.h"
 
-RCS_ID("$Id: EOUtilities.m,v 1.8 2004/01/29 13:23:22 ayers Exp $")
+RCS_ID("$Id: EOUtilities.m,v 1.9 2004/03/19 16:41:19 ayers Exp $")
 
-#ifndef NeXT_Foundation_LIBRARY
+#ifdef GNUSTEP
 #include <Foundation/NSString.h>
 #include <Foundation/NSArray.h>
 #include <Foundation/NSDictionary.h>
