@@ -12,8 +12,8 @@
    Author: Manuel Guesdon <mguesdon@orange-concept.com>
    Date: October 2000
 
-   $Revision: 1.18 $
-   $Date: 2004/02/26 10:33:10 $
+   $Revision: 1.20 $
+   $Date: 2004/03/19 16:41:19 $
 
    <abstract></abstract>
 
@@ -39,10 +39,10 @@
 
 #include "config.h"
 
-RCS_ID("$Id: Postgres95Channel.m,v 1.18 2004/02/26 10:33:10 ayers Exp $")
+RCS_ID("$Id: Postgres95Channel.m,v 1.20 2004/03/19 16:41:19 ayers Exp $")
 
 
-#ifndef NeXT_Foundation_LIBRARY
+#ifdef GNUSTEP
 #include <Foundation/NSArray.h>
 #include <Foundation/NSDictionary.h>
 #include <Foundation/NSString.h>
@@ -1786,6 +1786,41 @@ each key
   return model;
 }
 
+/* extensions for login panel */
+- (NSArray *)describeDatabaseNames
+{
+  NSMutableArray *databaseNames = [NSMutableArray array]; 
+  NSString *stmt = [NSS_SWF:@"SELECT datname FROM pg_database LEFT JOIN pg_user "
+                            @"ON datdba = usesysid ORDER BY 1"];
+  int i; 
+  _pgResult = PQexec(_pgConn, [stmt cString]);
+  for (i=0; i < PQntuples(_pgResult); i++)
+    {
+      [databaseNames addObject: [NSString stringWithCString:PQgetvalue(_pgResult,i,0)]]; 
+    }
+  return (NSArray *)databaseNames;
+}
+
+- (BOOL) userNameIsAdministrative:(NSString *)userName
+{
+  NSString *stmt = [NSS_SWF:@"SELECT usecreatedb FROM pg_user WHERE "
+                            @"usename = '%@'",userName]; 
+  _pgResult = PQexec(_pgConn, [stmt cString]);
+  if (_pgResult != NULL)
+    if (PQntuples(_pgResult))
+      {
+        const char *bytes;
+	
+	bytes = PQgetvalue(_pgResult,0,0); 
+        if (((char *)bytes)[0] == 't' && ((char *)bytes)[1] == 0)
+          return YES;
+        if (((char *)bytes)[0] == 'f' && ((char *)bytes)[1] == 0)
+          return NO;
+     
+      }
+  return NO; 
+}
+
 - (void)setDelegate:delegate
 {
   [super setDelegate: delegate];
