@@ -6,8 +6,8 @@
    Author: Mirko Viviani <mirko.viviani@rccr.cremona.it>
    Date: February 2000
 
-   $Revision: 1.15 $
-   $Date: 2004/02/25 12:52:59 $
+   $Revision: 1.18 $
+   $Date: 2004/03/29 14:40:15 $
 
    <abstract></abstract>
 
@@ -34,9 +34,9 @@
 
 #include "config.h"
 
-RCS_ID("$Id: Postgres95SQLExpression.m,v 1.15 2004/02/25 12:52:59 ayers Exp $")
+RCS_ID("$Id: Postgres95SQLExpression.m,v 1.18 2004/03/29 14:40:15 ayers Exp $")
 
-#ifndef NeXT_Foundation_LIBRARY
+#ifdef GNUSTEP
 #include <Foundation/NSUtilities.h>
 #include <Foundation/NSException.h>
 #else
@@ -344,7 +344,7 @@ RCS_ID("$Id: Postgres95SQLExpression.m,v 1.15 2004/02/25 12:52:59 ayers Exp $")
   databaseName = [connDict objectForKey: @"databaseName"];
   expr = [self expressionForString: nil];
   databaseName = [expr sqlStringForSchemaObjectName: databaseName];
-  stmt = [NSString stringWithFormat:@"DROP DATABASE \"%@\"", databaseName];
+  stmt = [NSString stringWithFormat:@"DROP DATABASE %@", databaseName];
   [expr setStatement: stmt];
   newArray = [NSArray arrayWithObject: expr];
   
@@ -658,4 +658,21 @@ RCS_ID("$Id: Postgres95SQLExpression.m,v 1.15 2004/02/25 12:52:59 ayers Exp $")
   return finalEntitiesString;
 }
 
+- (NSString *)columnTypeStringForAttribute:(EOAttribute *)attribute
+{
+  NSString *extType = [attribute externalType];
+  NSString *columnTypeString = nil;
+
+  if ([extType isEqualToString: @"text"])
+    {
+      columnTypeString = [NSString stringWithFormat: @"%@", extType];
+    }
+  else
+    {
+      columnTypeString = [super columnTypeStringForAttribute: attribute];
+    }
+
+  return columnTypeString;
+}
+
 @end
