@@ -9,8 +9,8 @@
    Author: Manuel Guesdon <mguesdon@orange-concept.com>
    Date: November 2001
 
-   $Revision: 1.20 $
-   $Date: 2004/02/12 12:08:16 $
+   $Revision: 1.21 $
+   $Date: 2004/03/19 16:41:19 $
 
    <abstract></abstract>
 
@@ -36,9 +36,9 @@
 
 #include "config.h"
 
-RCS_ID("$Id: EOClassDescription.m,v 1.20 2004/02/12 12:08:16 ayers Exp $")
+RCS_ID("$Id: EOClassDescription.m,v 1.21 2004/03/19 16:41:19 ayers Exp $")
 
-#ifndef NeXT_Foundation_LIBRARY
+#ifdef GNUSTEP
 #include <Foundation/NSString.h>
 #include <Foundation/NSArray.h>
 #include <Foundation/NSDictionary.h>
