@@ -9,8 +9,8 @@
    Author: Manuel Guesdon <mguesdon@orange-concept.com>
    Date: October 2000
 
-   $Revision: 1.20 $
-   $Date: 2004/02/12 11:07:49 $
+   $Revision: 1.21 $
+   $Date: 2004/03/19 16:41:20 $
 
    <abstract></abstract>
 
@@ -36,9 +36,9 @@
 
 #include "config.h"
 
-RCS_ID("$Id: EOGenericRecord.m,v 1.20 2004/02/12 11:07:49 ayers Exp $")
+RCS_ID("$Id: EOGenericRecord.m,v 1.21 2004/03/19 16:41:20 ayers Exp $")
 
-#ifndef NeXT_Foundation_LIBRARY
+#ifdef GNUSTEP
 #include <Foundation/NSArray.h>
 #include <Foundation/NSAutoreleasePool.h>
 #include <Foundation/NSDictionary.h>
