@@ -6,8 +6,8 @@
    Author: Manuel Guesdon <mguesdon@orange-concept.com>
    Date: October 2000
 
-   $Revision: 1.11 $
-   $Date: 2004/01/31 13:57:38 $
+   $Revision: 1.12 $
+   $Date: 2004/03/19 16:41:20 $
 
    <abstract></abstract>
 
@@ -33,9 +33,9 @@
 
 #include "config.h"
 
-RCS_ID("$Id: EOMutableKnownKeyDictionary.m,v 1.11 2004/01/31 13:57:38 ayers Exp $")
+RCS_ID("$Id: EOMutableKnownKeyDictionary.m,v 1.12 2004/03/19 16:41:20 ayers Exp $")
 
-#ifndef NeXT_Foundation_LIBRARY
+#ifdef GNUSTEP
 #include <Foundation/NSArray.h>
 #include <Foundation/NSString.h>
 #include <Foundation/NSDictionary.h>
