@@ -1,4 +1,4 @@
-/* 
+/* -*-objc-*-
    EONull.h
 
    Copyright (C) 1996-2002, 2003 Free Software Foundation, Inc.
@@ -27,7 +27,7 @@
 #ifndef __EONull_h__
 #define __EONull_h__
 
-#ifndef NeXT_Foundation_LIBRARY
+#ifdef GNUSTEP
 #include <Foundation/NSNull.h>
 #else
 #include <Foundation/Foundation.h>
