@@ -6,8 +6,8 @@
    Author: Mirko Viviani <mirko.viviani@rccr.cremona.it>
    Date: February 2000
 
-   $Revision: 1.20 $
-   $Date: 2004/02/12 10:28:09 $
+   $Revision: 1.21 $
+   $Date: 2004/03/19 16:41:20 $
 
    <abstract></abstract>
 
@@ -33,12 +33,12 @@
 
 #include "config.h"
 
-RCS_ID("$Id: EOQualifier.m,v 1.20 2004/02/12 10:28:09 ayers Exp $")
+RCS_ID("$Id: EOQualifier.m,v 1.21 2004/03/19 16:41:20 ayers Exp $")
 
 #include <stdio.h>
 #include <string.h>
 
-#ifndef NeXT_Foundation_LIBRARY
+#ifdef GNUSTEP
 #include <Foundation/NSDictionary.h>
 #include <Foundation/NSSet.h>
 #include <Foundation/NSScanner.h>
