@@ -6,8 +6,8 @@
    Author: Stephane Corthesy <stephane@sente.ch>
    Date: February 2003
 
-   $Revision: 1.4 $
-   $Date: 2003/08/25 20:01:59 $
+   $Revision: 1.5 $
+   $Date: 2004/03/19 16:41:21 $
 
    <abstract></abstract>
 
@@ -33,9 +33,9 @@
 
 #include "config.h"
 
-RCS_ID("$Id: eoutil.m,v 1.4 2003/08/25 20:01:59 ayers Exp $")
+RCS_ID("$Id: eoutil.m,v 1.5 2004/03/19 16:41:21 ayers Exp $")
 
-#ifndef NeXT_Foundation_LIBRARY
+#ifdef GNUSTEP
 #include <Foundation/NSArray.h>
 #include <Foundation/NSString.h>
 #include <Foundation/NSDecimalNumber.h>
